@@ -1,23 +1,26 @@
-varbin <-
-function(n, m, alpha = 0.05, R = 5000){
-	
-	dat <- data.frame(n = n, m = m)
-
-  n <- dat$n; m <- dat$m; N <- length(n); ntot <- sum(n); mtot <- sum(m)
+varbin <- function(n, m, alpha = 0.05, R = 5000) {
   
-	# binomial
+  dat <- data.frame(n = n, m = m)
+  
+  n <- dat$n
+  m <- dat$m
+  N <- length(n)
+  ntot <- sum(n)
+  mtot <- sum(m)
+  
+  # binomial
   mu <- mtot / ntot
   varmu <- mu * (1 - mu) / (ntot - 1)
   
-	# ratio
+  # ratio
   muratio <- mu
   varmuratio <- N * (N - 1)^(-1) * ntot^(-2) * sum((m - n * mu)^2)
   
-	# arithmetic
+  # arithmetic
   muarithm <- mean(m / n)
   varmuarithm <- var(m / n) / N
   
-	# jackknife
+  # jackknife
   z <- (m - n * mu) / (ntot - n)
   pseudovalue <- mu + (N - 1) * z
   #mujack <- mu + (N - 1) * mean(z)
@@ -33,18 +36,18 @@ function(n, m, alpha = 0.05, R = 5000){
   muboot <- mean(res$t)
   varmuboot <- var(res$t)
   
-	# results
+  # results
   tab <- data.frame(mu = c(mu, muratio, muarithm, mujack, muboot),
                     varmu = c(varmu, varmuratio, varmuarithm, varmujack, varmuboot))
-  tab$lower <- pmax(0, tab$mu - qnorm(1 - alpha/2) * sqrt(tab$varmu))
-  tab$upper <- pmin(1, tab$mu + qnorm(1 - alpha/2) * sqrt(tab$varmu))
+  tab$lower <- pmax(0, tab$mu - qnorm(1 - alpha / 2) * sqrt(tab$varmu))
+  tab$upper <- pmin(1, tab$mu + qnorm(1 - alpha / 2) * sqrt(tab$varmu))
   rownames(tab) <- c("Binomial", "Ratio", "Arithmetic", "Jackknife", "Bootstrap")
   features <- c(N = N, n = ntot, m = mtot)
   
-	# outputs
+  # outputs
   structure(
-  	list(tab = tab, muboot = res$t, alpha = alpha, features = features, dat = dat),
-  	class = "varbin"
-  	)
-
+    list(tab = tab, muboot = res$t, alpha = alpha, features = features, dat = dat),
+    class = "varbin"
+  )
+  
 }
